/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VFloatArray;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsFloat;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeFloat;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVFloatArray;

/**
 * Type adapter that convert from {@link ChannelAccessControlsFloat} and
 * {@link ChannelAccessTimeFloat} to {@link VFloatArray}.
 * 
 * @author Sebastian Marsching
 */
public class ArrayFloatTypeAdapter
        extends JackieDataSourceTypeAdapter<VFloatArray> {

    /**
     * Single instance of this adapter.
     */
    public static final ArrayFloatTypeAdapter INSTANCE = new ArrayFloatTypeAdapter();

    private ArrayFloatTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_FLOAT, VFloatArray.class);
    }

    @Override
    protected VFloatArray convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_FLOAT and we thus know that the
        // monitors return a DBR_CTRL_FLOAT and DBR_TIME_FLOAT.
        ChannelAccessControlsFloat controlsValue = (ChannelAccessControlsFloat) message
                .getControlsValue();
        ChannelAccessTimeFloat timeValue = (ChannelAccessTimeFloat) message
                .getTimeValue();
        return new JackieVFloatArray(controlsValue, timeValue,
                connection.getDisconnectTime(),
                connection.isHonorZeroPrecision());
    }

}
